# komposer

## To-do

- disallow port mapping form docker compose
- set ingress annotations from CLI as file
- set deployment annotations from CLI as file
- accept repository and branch name only as kubernetes names
- set ingress paths from CLI
- needs the ingress class name, mandatory if ingress is selected
- set custom resource limits
